"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLastRelease = getLastRelease;
exports.getLastDraftReleaseTag = getLastDraftReleaseTag;
exports.getDraftReleaseTags = getDraftReleaseTags;
exports.getOpenReleasePRs = getOpenReleasePRs;

var _lodash = _interopRequireDefault(require("lodash"));

var _graphqlTag = _interopRequireDefault(require("graphql-tag"));

var _path = _interopRequireDefault(require("path"));

var _debug = _interopRequireDefault(require("debug"));

var _restClient = require("@shelf/gh-sdk/lib/rest-client");

var _client = require("./client");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = (0, _debug.default)(`${require('../package').name}:${_path.default.basename(__filename)}`);

async function getLastRelease({
  org,
  repo
}) {
  const gh = (0, _restClient.getClient)();

  try {
    const {
      data
    } = await gh.repos.getLatestRelease({
      owner: org,
      repo
    });
    return data.tag_name;
  } catch (error) {
    return 'v0.0.0';
  }
}

async function getLastDraftReleaseTag({
  org,
  repo
}) {
  try {
    const draftReleaseTags = await getDraftReleaseTags({
      org,
      repo
    });
    return _lodash.default.first(_lodash.default.map(draftReleaseTags, 'tag'));
  } catch (error) {
    return '';
  }
}

async function getDraftReleaseTags({
  org,
  repo
}) {
  const gh = (0, _restClient.getClient)();

  try {
    const {
      data
    } = await gh.repos.listReleases({
      owner: org,
      repo
    });

    const draftReleases = _lodash.default.filter(data, {
      draft: true
    });

    return _lodash.default.compact(_lodash.default.map(draftReleases, release => {
      return {
        tag: release.tag_name,
        id: release.id
      };
    }));
  } catch (error) {
    return [];
  }
}

async function getOpenReleasePRs({
  org,
  repo
}) {
  const gh = (0, _client.getClientGraphQL)();
  debug('Loading release PRs for repo %s', repo);
  const {
    data: {
      organization: {
        repository: {
          pullRequests: {
            nodes
          }
        }
      }
    }
  } = await gh.query({
    query: (0, _graphqlTag.default)`
      {
        organization(login: "${org}") {
          repository(name: "${repo}") {
            pullRequests(states: [OPEN], labels: ["release"], first: 10) {
              nodes {
                title
                baseRefName
                headRefName
                mergeable
                number
                viewerCanUpdate
                labels(first: 10) {
                  nodes {
                    name
                  }
                }
                reviews(first: 10) {
                  nodes {
                    state
                    author {
                      login
                    }
                  }
                }
              }
            }
          }
        }
      }
    `
  });
  return nodes;
}