"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLastDevelopCommitSHA = getLastDevelopCommitSHA;
exports.createReleaseBranch = createReleaseBranch;
exports.createReleaseNotes = createReleaseNotes;
exports.createReleasePR = createReleasePR;

var _lodash = _interopRequireDefault(require("lodash"));

var _restClient = require("@shelf/gh-sdk/lib/rest-client");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function getLastDevelopCommitSHA({
  org,
  repo
}) {
  const gh = (0, _restClient.getClient)();
  const {
    data
  } = await gh.repos.getBranch({
    owner: org,
    repo,
    branch: 'develop',
    per_page: 1
  });
  return _lodash.default.get(data, 'commit.sha', '');
}

async function createReleaseBranch({
  org,
  repo,
  version,
  commitHash
}) {
  const gh = (0, _restClient.getClient)();
  const branchName = `refs/heads/release/v${version}`;
  const {
    data
  } = await gh.gitdata.createRef({
    owner: org,
    repo,
    ref: branchName,
    sha: commitHash
  });
  return data;
}

async function createReleaseNotes({
  org,
  repo,
  version,
  releaseTitle
}) {
  const gh = (0, _restClient.getClient)();
  const tagName = `v${version}`;
  const {
    data
  } = await gh.repos.createRelease({
    owner: org,
    repo,
    tag_name: tagName,
    target_commitish: `release/${tagName}`,
    name: `Release ${tagName}: ${releaseTitle}`,
    draft: true
  });
  return data;
}

async function createReleasePR({
  org,
  repo,
  version,
  releaseTitle
}) {
  const gh = (0, _restClient.getClient)();
  const tagName = `v${version}`;
  const branch = `release/${tagName}`;
  const {
    data
  } = await gh.pullRequests.create({
    owner: org,
    repo,
    head: branch,
    base: 'master',
    title: `Release ${tagName}: ${releaseTitle}`
  });
  return data;
}