"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepareRelease = prepareRelease;

var _logSymbols = _interopRequireDefault(require("log-symbols"));

var _githubLabels = require("./github-labels");

var _helpersLabels = require("./helpers-labels");

var _github = require("./github");

var _inquirer = require("./inquirer");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function prepareRelease({
  org,
  repo
}) {
  try {
    const version = await (0, _inquirer.askNewReleaseVersion)({
      org,
      repo
    });
    const commitHash = await (0, _github.getLastDevelopCommitSHA)({
      org,
      repo
    });
    await (0, _github.createReleaseBranch)({
      org,
      repo,
      version,
      commitHash
    });
    console.log(_logSymbols.default.success, `Created branch release/v${version}!`);
    const releaseTitle = await (0, _inquirer.askReleaseTitle)({
      org,
      repo
    });
    await (0, _github.createReleaseNotes)({
      org,
      repo,
      version,
      releaseTitle
    });
    console.log(_logSymbols.default.success, `Created Release Notes!`);
    const {
      number
    } = await (0, _github.createReleasePR)({
      org,
      repo,
      version,
      releaseTitle
    });
    console.log(_logSymbols.default.success, `Created Pull Request #${number}!`);

    if (!(await (0, _helpersLabels.hasReleaseLabel)({
      org,
      repo
    }))) {
      console.log(_logSymbols.default.warning, `No Release Label Found`);
      await (0, _githubLabels.createReleaseLabel)({
        org,
        repo
      });
      console.log(_logSymbols.default.success, `Created Release Label!`);
    }

    await (0, _githubLabels.assignReleaseLabel)({
      org,
      repo,
      pr: number
    });
    console.log(_logSymbols.default.success, `Assigned Release Label to PR #${number}!`);
    await (0, _inquirer.askToOpenPR)({
      org,
      repo,
      pr: number
    });
  } catch (error) {
    console.log(_logSymbols.default.error, error.message);
  }
}